# Tegridy MIDI

## Tools for reading, writing, and manipulating MIDIs

![Tegridy MIDI Logo](https://github.com/user-attachments/assets/6b1f98e1-255c-4e76-ba24-46f37ad36b46)

***

## Features

- Read and write MIDI files
- Manipulate MIDI data
- Integrate with FluidSynth for MIDI playback

***

## Installation

### CPU

```sh
pip install tegridymidi
```

### GPU

```sh
pip install tegridymidi[cuda]
```

***

### Project Los Angeles
### Tegridy Code 2024
